==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/AKSSchemaPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ClusterPurpose
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.LoadBalancerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * AKS properties
 * @property agentCount Number of agents
 * @property agentVmSize Agent virtual machine size
 * @property aksNetworkingConfiguration AKS networking configuration for vnet
 * @property clusterFqdn Cluster full qualified domain name
 * @property clusterPurpose Intended usage of the cluster
 * @property loadBalancerSubnet Load Balancer Subnet
 * @property loadBalancerType Load Balancer Type
 * @property sslConfiguration SSL configuration
 */
public data class AKSSchemaPropertiesArgs(
    public val agentCount: Output<Int>? = null,
    public val agentVmSize: Output<String>? = null,
    public val aksNetworkingConfiguration: Output<AksNetworkingConfigurationArgs>? = null,
    public val clusterFqdn: Output<String>? = null,
    public val clusterPurpose: Output<Either<String, ClusterPurpose>>? = null,
    public val loadBalancerSubnet: Output<String>? = null,
    public val loadBalancerType: Output<Either<String, LoadBalancerType>>? = null,
    public val sslConfiguration: Output<SslConfigurationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs.builder()
            .agentCount(agentCount?.applyValue({ args0 -> args0 }))
            .agentVmSize(agentVmSize?.applyValue({ args0 -> args0 }))
            .aksNetworkingConfiguration(
                aksNetworkingConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .clusterFqdn(clusterFqdn?.applyValue({ args0 -> args0 }))
            .clusterPurpose(
                clusterPurpose?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .loadBalancerSubnet(loadBalancerSubnet?.applyValue({ args0 -> args0 }))
            .loadBalancerType(
                loadBalancerType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .sslConfiguration(
                sslConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [AKSSchemaPropertiesArgs].
 */
@PulumiTagMarker
public class AKSSchemaPropertiesArgsBuilder internal constructor() {
    private var agentCount: Output<Int>? = null

    private var agentVmSize: Output<String>? = null

    private var aksNetworkingConfiguration: Output<AksNetworkingConfigurationArgs>? = null

    private var clusterFqdn: Output<String>? = null

    private var clusterPurpose: Output<Either<String, ClusterPurpose>>? = null

    private var loadBalancerSubnet: Output<String>? = null

    private var loadBalancerType: Output<Either<String, LoadBalancerType>>? = null

    private var sslConfiguration: Output<SslConfigurationArgs>? = null

    /**
     * @param value Number of agents
     */
    @JvmName("wdrrrobawtqcfmkw")
    public suspend fun agentCount(`value`: Output<Int>) {
        this.agentCount = value
    }

    /**
     * @param value Agent virtual machine size
     */
    @JvmName("wvglvcbnguywqkmh")
    public suspend fun agentVmSize(`value`: Output<String>) {
        this.agentVmSize = value
    }

    /**
     * @param value AKS networking configuration for vnet
     */
    @JvmName("ixlxfiikecwjlsdc")
    public suspend fun aksNetworkingConfiguration(`value`: Output<AksNetworkingConfigurationArgs>) {
        this.aksNetworkingConfiguration = value
    }

    /**
     * @param value Cluster full qualified domain name
     */
    @JvmName("galemdktmadmnvhp")
    public suspend fun clusterFqdn(`value`: Output<String>) {
        this.clusterFqdn = value
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("jmixiwxqasynlfnj")
    public suspend fun clusterPurpose(`value`: Output<Either<String, ClusterPurpose>>) {
        this.clusterPurpose = value
    }

    /**
     * @param value Load Balancer Subnet
     */
    @JvmName("oitfscunmunxgxgj")
    public suspend fun loadBalancerSubnet(`value`: Output<String>) {
        this.loadBalancerSubnet = value
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("jpwxcytpyvjhcrax")
    public suspend fun loadBalancerType(`value`: Output<Either<String, LoadBalancerType>>) {
        this.loadBalancerType = value
    }

    /**
     * @param value SSL configuration
     */
    @JvmName("rjidvgdmttrnnjhl")
    public suspend fun sslConfiguration(`value`: Output<SslConfigurationArgs>) {
        this.sslConfiguration = value
    }

    /**
     * @param value Number of agents
     */
    @JvmName("agpdkjsphcwfuxwx")
    public suspend fun agentCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.agentCount = mapped
    }

    /**
     * @param value Agent virtual machine size
     */
    @JvmName("mirxhpwjhrktqmdj")
    public suspend fun agentVmSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.agentVmSize = mapped
    }

    /**
     * @param value AKS networking configuration for vnet
     */
    @JvmName("kwkhwjvniifxpqrt")
    public suspend fun aksNetworkingConfiguration(`value`: AksNetworkingConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.aksNetworkingConfiguration = mapped
    }

    /**
     * @param argument AKS networking configuration for vnet
     */
    @JvmName("esferglligkwqptn")
    public suspend
    fun aksNetworkingConfiguration(argument: suspend AksNetworkingConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = AksNetworkingConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.aksNetworkingConfiguration = mapped
    }

    /**
     * @param value Cluster full qualified domain name
     */
    @JvmName("ovjauuqfomftcdvm")
    public suspend fun clusterFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterFqdn = mapped
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("bpmmgtqfdftftwnw")
    public suspend fun clusterPurpose(`value`: Either<String, ClusterPurpose>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterPurpose = mapped
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("bceemaylgtvsmtdn")
    public fun clusterPurpose(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClusterPurpose>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterPurpose = mapped
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("cfkjakhpgwhpjdou")
    public fun clusterPurpose(`value`: ClusterPurpose) {
        val toBeMapped = Either.ofRight<String, ClusterPurpose>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterPurpose = mapped
    }

    /**
     * @param value Load Balancer Subnet
     */
    @JvmName("yvuxevbopnlmoqyq")
    public suspend fun loadBalancerSubnet(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerSubnet = mapped
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("abjcmujhwbifsjec")
    public suspend fun loadBalancerType(`value`: Either<String, LoadBalancerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerType = mapped
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("okydcbxqwebgeqrt")
    public fun loadBalancerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.loadBalancerType = mapped
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("osqfkspixrylfosd")
    public fun loadBalancerType(`value`: LoadBalancerType) {
        val toBeMapped = Either.ofRight<String, LoadBalancerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.loadBalancerType = mapped
    }

    /**
     * @param value SSL configuration
     */
    @JvmName("keniqqdvyiuuuqmf")
    public suspend fun sslConfiguration(`value`: SslConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslConfiguration = mapped
    }

    /**
     * @param argument SSL configuration
     */
    @JvmName("vgxtjbswppsklvhq")
    public suspend fun sslConfiguration(argument: suspend SslConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = SslConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sslConfiguration = mapped
    }

    internal fun build(): AKSSchemaPropertiesArgs = AKSSchemaPropertiesArgs(
        agentCount = agentCount,
        agentVmSize = agentVmSize,
        aksNetworkingConfiguration = aksNetworkingConfiguration,
        clusterFqdn = clusterFqdn,
        clusterPurpose = clusterPurpose,
        loadBalancerSubnet = loadBalancerSubnet,
        loadBalancerType = loadBalancerType,
        sslConfiguration = sslConfiguration,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/AKSSchemaPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ClusterPurpose
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.LoadBalancerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * AKS properties
 * @property agentCount Number of agents
 * @property agentVmSize Agent virtual machine size
 * @property aksNetworkingConfiguration AKS networking configuration for vnet
 * @property clusterFqdn Cluster full qualified domain name
 * @property clusterPurpose Intended usage of the cluster
 * @property loadBalancerSubnet Load Balancer Subnet
 * @property loadBalancerType Load Balancer Type
 * @property sslConfiguration SSL configuration
 */
public data class AKSSchemaPropertiesArgs(
    public val agentCount: Output<Int>? = null,
    public val agentVmSize: Output<String>? = null,
    public val aksNetworkingConfiguration: Output<AksNetworkingConfigurationArgs>? = null,
    public val clusterFqdn: Output<String>? = null,
    public val clusterPurpose: Output<Either<String, ClusterPurpose>>? = null,
    public val loadBalancerSubnet: Output<String>? = null,
    public val loadBalancerType: Output<Either<String, LoadBalancerType>>? = null,
    public val sslConfiguration: Output<SslConfigurationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.AKSSchemaPropertiesArgs.builder()
            .agentCount(agentCount?.applyValue({ args0 -> args0 }))
            .agentVmSize(agentVmSize?.applyValue({ args0 -> args0 }))
            .aksNetworkingConfiguration(
                aksNetworkingConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .clusterFqdn(clusterFqdn?.applyValue({ args0 -> args0 }))
            .clusterPurpose(
                clusterPurpose?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .loadBalancerSubnet(loadBalancerSubnet?.applyValue({ args0 -> args0 }))
            .loadBalancerType(
                loadBalancerType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .sslConfiguration(
                sslConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [AKSSchemaPropertiesArgs].
 */
@PulumiTagMarker
public class AKSSchemaPropertiesArgsBuilder internal constructor() {
    private var agentCount: Output<Int>? = null

    private var agentVmSize: Output<String>? = null

    private var aksNetworkingConfiguration: Output<AksNetworkingConfigurationArgs>? = null

    private var clusterFqdn: Output<String>? = null

    private var clusterPurpose: Output<Either<String, ClusterPurpose>>? = null

    private var loadBalancerSubnet: Output<String>? = null

    private var loadBalancerType: Output<Either<String, LoadBalancerType>>? = null

    private var sslConfiguration: Output<SslConfigurationArgs>? = null

    /**
     * @param value Number of agents
     */
    @JvmName("ctcmqtvjidrsiqhs")
    public suspend fun agentCount(`value`: Output<Int>) {
        this.agentCount = value
    }

    /**
     * @param value Agent virtual machine size
     */
    @JvmName("hmcwbxotlmhqkdpl")
    public suspend fun agentVmSize(`value`: Output<String>) {
        this.agentVmSize = value
    }

    /**
     * @param value AKS networking configuration for vnet
     */
    @JvmName("qeffphxoqwrwqpum")
    public suspend fun aksNetworkingConfiguration(`value`: Output<AksNetworkingConfigurationArgs>) {
        this.aksNetworkingConfiguration = value
    }

    /**
     * @param value Cluster full qualified domain name
     */
    @JvmName("wgugrilojfsmjehs")
    public suspend fun clusterFqdn(`value`: Output<String>) {
        this.clusterFqdn = value
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("fkcmughxgatwkojl")
    public suspend fun clusterPurpose(`value`: Output<Either<String, ClusterPurpose>>) {
        this.clusterPurpose = value
    }

    /**
     * @param value Load Balancer Subnet
     */
    @JvmName("dvcciyblncuourdj")
    public suspend fun loadBalancerSubnet(`value`: Output<String>) {
        this.loadBalancerSubnet = value
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("icibdewgshlhovtx")
    public suspend fun loadBalancerType(`value`: Output<Either<String, LoadBalancerType>>) {
        this.loadBalancerType = value
    }

    /**
     * @param value SSL configuration
     */
    @JvmName("ctmbjosrsbndseds")
    public suspend fun sslConfiguration(`value`: Output<SslConfigurationArgs>) {
        this.sslConfiguration = value
    }

    /**
     * @param value Number of agents
     */
    @JvmName("rmonwnxorffocojy")
    public suspend fun agentCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.agentCount = mapped
    }

    /**
     * @param value Agent virtual machine size
     */
    @JvmName("omcbrrdxedratysd")
    public suspend fun agentVmSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.agentVmSize = mapped
    }

    /**
     * @param value AKS networking configuration for vnet
     */
    @JvmName("cjnxasygkatvjinm")
    public suspend fun aksNetworkingConfiguration(`value`: AksNetworkingConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.aksNetworkingConfiguration = mapped
    }

    /**
     * @param argument AKS networking configuration for vnet
     */
    @JvmName("ljwioqrsvpknxmeo")
    public suspend
    fun aksNetworkingConfiguration(argument: suspend AksNetworkingConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = AksNetworkingConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.aksNetworkingConfiguration = mapped
    }

    /**
     * @param value Cluster full qualified domain name
     */
    @JvmName("snkawkmbqqjatsfm")
    public suspend fun clusterFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterFqdn = mapped
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("rnyhswtfrprmsbbo")
    public suspend fun clusterPurpose(`value`: Either<String, ClusterPurpose>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterPurpose = mapped
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("gluvegmqmxhiqlrr")
    public fun clusterPurpose(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClusterPurpose>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterPurpose = mapped
    }

    /**
     * @param value Intended usage of the cluster
     */
    @JvmName("pocyoackaekcfhsd")
    public fun clusterPurpose(`value`: ClusterPurpose) {
        val toBeMapped = Either.ofRight<String, ClusterPurpose>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterPurpose = mapped
    }

    /**
     * @param value Load Balancer Subnet
     */
    @JvmName("aetiemwmetwwxmeb")
    public suspend fun loadBalancerSubnet(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerSubnet = mapped
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("odrngfllrphtpqip")
    public suspend fun loadBalancerType(`value`: Either<String, LoadBalancerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerType = mapped
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("toijlgdutkldmlky")
    public fun loadBalancerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.loadBalancerType = mapped
    }

    /**
     * @param value Load Balancer Type
     */
    @JvmName("anxnibtpqjtjdirv")
    public fun loadBalancerType(`value`: LoadBalancerType) {
        val toBeMapped = Either.ofRight<String, LoadBalancerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.loadBalancerType = mapped
    }

    /**
     * @param value SSL configuration
     */
    @JvmName("mmqfyhrbjjqphedh")
    public suspend fun sslConfiguration(`value`: SslConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslConfiguration = mapped
    }

    /**
     * @param argument SSL configuration
     */
    @JvmName("mtusxhpmhxiemgwq")
    public suspend fun sslConfiguration(argument: suspend SslConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = SslConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sslConfiguration = mapped
    }

    internal fun build(): AKSSchemaPropertiesArgs = AKSSchemaPropertiesArgs(
        agentCount = agentCount,
        agentVmSize = agentVmSize,
        aksNetworkingConfiguration = aksNetworkingConfiguration,
        clusterFqdn = clusterFqdn,
        clusterPurpose = clusterPurpose,
        loadBalancerSubnet = loadBalancerSubnet,
        loadBalancerType = loadBalancerType,
        sslConfiguration = sslConfiguration,
    )
}
